# FORCE NOARCH
# This package is noarch intentionally, although it supplies binaries,
# as they're not intended for the build platform, but for AVR.
# The related discussion can be found here:
# https://www.redhat.com/archives/fedora-devel-list/2009-February/msg02261.html
%global _binaries_in_noarch_packages_terminate_build 0

%define	target avr

Name:		%{target}-libc
Version:	1.7.1
Release:	%mkrel 15
Summary:	C library for use with GCC on Atmel AVR microcontrollers
Group:		Development/C
License:	BSD
URL:		https://www.nongnu.org/avr-libc/
Source0:	https://download.savannah.gnu.org/releases/avr-libc/avr-libc-%{version}.tar.bz2
Source1:	https://download.savannah.gnu.org/releases/avr-libc/avr-libc-user-manual-%{version}.tar.bz2
Source2:	https://download.savannah.gnu.org/releases/avr-libc/avr-libc-user-manual-%{version}.pdf.bz2
Patch0:		avr-libc-1.6.4-documentation.patch
Patch1:		avr-libc-1.7.1-PSTR.patch
# backport from upstream 1.8.1
Patch2:		avr-libc-1.7.1-fix_missing_include_in_delay_h.patch

BuildRequires:	cross-avr-gcc 
BuildRequires:	doxygen 
BuildRequires:	transfig 
BuildRequires:	netpbm 
BuildRequires:	texlive-texmf 
BuildRequires:	texlive
BuildArch:	noarch

%description
AVR Libc is a Free Software project whose goal is to provide a high quality C
library for use with GCC on Atmel AVR microcontrollers.

AVR Libc is licensed under a single unified license. This so-called modified
Berkeley license is intented to be compatible with most Free Software licenses
like the GPL, yet impose as little restrictions for the use of the library in
closed-source commercial applications as possible.

%files
%dir %{_prefix}/avr
%dir %{_docdir}/%{name}-%{version}
%doc %{_docdir}/%{name}-%{version}/AUTHORS
%doc %{_docdir}/%{name}-%{version}/C*
%doc %{_docdir}/%{name}-%{version}/LICENSE
%doc %{_docdir}/%{name}-%{version}/NEWS
%doc %{_docdir}/%{name}-%{version}/README
%doc %{_docdir}/%{name}-%{version}/TODO
%doc %{_docdir}/%{name}-%{version}/examples
%{_prefix}/avr/include
%{_prefix}/avr/lib
%{_bindir}/avr-man

#--------------------------------------------------------------------

%package docs
Summary:        AVR C library docs in html and pdf format
Group:          Development/C
Requires:       %{name} = %{version}-%{release}

%description docs
This package contains the AVR C library docs in html and pdf format, the main
package already contains the docs in man-page format (use "avr-man xxxx" to
access these).

%files docs
%doc html/
%doc pdf/

#--------------------------------------------------------------------

%prep
%setup -q -a1 
%patch0 -p0
%patch1 -p0
%patch2 -p1

# Add html docs
mkdir html
cd html/
bzip2 -dc %SOURCE1 | tar -xvvf -
cd -
# Add pdf manual
mkdir pdf
cd pdf/
bzip2 -dc %SOURCE2 > avr-libc-user-manual-%{version}.pdf
cd -

for i in doc/api/faq.dox doc/api/overview.dox include/stdio.h include/stdlib.h;
  do
    iconv -f CP1252 -t UTF8 $i > tmp
    mv tmp $i
done
#sed -i 's|@DOC_INST_DIR@/man|%{_prefix}/avr/share/man|' scripts/avr-man.in


%build
autoreconf -vfi
# The ps doc ways in at 7Mb versus 2.5 for the pdf and has little added value
./configure --prefix=%{_prefix} --host=avr --build=`./config.guess` # --enable-doc
# don't use %{?_smp_mflags}, it breaks the build
make

%install
make install DESTDIR=$RPM_BUILD_ROOT

#mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/man
# put the man-pages in the FHS mandir and gzip them
#mkdir -p $RPM_BUILD_ROOT%{_prefix}/avr/share
#mv $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/man \
#  $RPM_BUILD_ROOT%{_prefix}/avr/share
#gzip $RPM_BUILD_ROOT%{_prefix}/avr/share/man/man3/*

# we only want to use %doc with an absolute path to avoid rpmbuild from erasing
# %{_docdir}/%{name}-%{version}
install -p -m 644 doc/TODO doc/CHANGES.old AUTHORS ChangeLog* LICENSE NEWS \
  README $RPM_BUILD_ROOT%{_docdir}/%name-%{version}



%changelog
* Mon Mar 23 2020 danf <danf> 1.7.1-15.mga8
+ Revision: 1559152
- Fix ARM build by using newer autoconf

* Tue Feb 11 2020 umeabot <umeabot> 1.7.1-14.mga8
+ Revision: 1490312
- Mageia 8 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 1.7.1-13.mga7
+ Revision: 1261836
- Mageia 7 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 1.7.1-12.mga7
+ Revision: 1259952
- Mageia 7 Mass Rebuild

* Fri Feb 19 2016 umeabot <umeabot> 1.7.1-11.mga6
+ Revision: 969728
- Mageia 6 Mass Rebuild

* Sun Sep 06 2015 ycantin <ycantin> 1.7.1-10.mga6
+ Revision: 873736
- Add missing include in delay.h (mga #12919)

* Wed Oct 15 2014 umeabot <umeabot> 1.7.1-8.mga5
+ Revision: 745501
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.7.1-7.mga5
+ Revision: 678077
- Mageia 5 Mass Rebuild

* Tue Dec 03 2013 danf <danf> 1.7.1-6.mga4
+ Revision: 554838
- Removed hack to stop stripping binaries since it's unneeded on Mageia
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 10 2012 dmorgan <dmorgan> 1.7.1-3.mga2
+ Revision: 194611
- Sync with fedora version

* Wed Sep 14 2011 dmorgan <dmorgan> 1.7.1-2.mga2
+ Revision: 143591
- Remove noarch as we install files in %%_libdir ( mga #2743)
+ kicer86 <kicer86>
- Group changed to Development/C

* Sun Jul 17 2011 kicer86 <kicer86> 1.7.1-1.mga2
+ Revision: 125251
- prefix set to %%{_libdir}
- lots of cleanups
- imported package avr-libc

